==> texlive-lang_2016.20170123.orig.tar.xz: texlive-lang-2016.20170123/texmf-dist/doc/fonts/unfonts-core/README.md <==
# Un-Fonts core

This is TrueType version of Un-fonts "core" bundle as provided at

- http://kldp.net/unfonts/

The project maintainers are

- Won-kyu Park <wkpark@kldp.org>
- Jungshik Shin <jshin@mailaps.org>

The original Type1 fonts, created by Koaunghi Un, are also available
as part of HLaTeX (Korean TeX):

- http://mirror.ctan.org/fonts/korean/HLaTeX

## Contents

This bundle includes core Korean font families (12 fonts):

- UnBatang, UnBatangBold: serif
- UnDotum, UnDotumBold: sans-serif
- UnGraphic, UnGraphicBold: sans-serif style
- UnDinaru, UnDinaruBold, UnDinaruLight
- UnPilgi, UnPilgiBold: script
- UnGungseo: cursive, brush-stroke

## Copyright

These fonts are distributed under GPLv2.
Copyright (c) 1998-2004 Koanughi Un.

## Changes on CTAN

- 2016-09-19 Un Fonts core v1.0.2
  (the original archive "2607-un-fonts-core-1.0.2-080608.tar.gz" was re-packaged)

## Note

This bundle has been uploaded to CTAN by Hironobu Yamashita.
Inquiries and comments should be sent to <h.y.acetaminophen@gmail.com>.

Below is some additional notes from README.debian (included in ttf-unfonts-core)

## GPL and font embedding

These fonts are under the (pure) GNU General Public License, with no
exception about embedding in a document. So you should take care
about the license influence when your non-GPLed document embeds one of
these fonts.

This licensing problem has already been reported to the upstream years
ago but the upstream was not active on this discussion. Currently the
upstream looks dead.

For your information about this issue:

- The font embedding exception which FSF suggests:
  http://www.fsf.org/licensing/licenses/gpl-faq.html#FontException
- Fedora wiki page about font licensing:
  http://fedoraproject.org/wiki/SIGs/Fonts/Legal

More upstream information (in Korean):

- http://faq.ktug.or.kr/faq/%C0%BA%B1%DB%B2%C3

Hironobu Yamashita
2016-09-19

==> texlive-lang_2017.20180305.orig.tar.xz: texlive-lang-2017.20180305/texmf-dist/doc/fonts/unfonts-core/README.md <==
# Un-Fonts core

This is TrueType version of Un-fonts "core" bundle as provided at

- http://kldp.net/unfonts/

The project maintainers are

- Won-kyu Park <wkpark@kldp.org>
- Jungshik Shin <jshin@mailaps.org>

The original Type1 fonts, created by Koaunghi Un, are also available
as part of HLaTeX (Korean TeX):

- http://mirror.ctan.org/fonts/korean/HLaTeX

## Contents

This bundle includes core Korean font families (12 fonts):

- UnBatang, UnBatangBold: serif
- UnDotum, UnDotumBold: sans-serif
- UnGraphic, UnGraphicBold: sans-serif style
- UnDinaru, UnDinaruBold, UnDinaruLight
- UnPilgi, UnPilgiBold: script
- UnGungseo: cursive, brush-stroke

## Copyright

These fonts are distributed under GPLv2.

Copyright: 1998-2008, Koaunghi Un
           2003, Park, Won-kyu <wkpark@chem.skku.ac.kr>
           2003, Jungshik Shin <jshin@mailaps.org>

The file changelog.Debian is distributed under GPLv2.

Copyright: 2003-2012, Changwoo Ryu <cwryu@debian.org>
           2010-2012, Hideki Yamane (Debian-JP) <henrich@debian.or.jp>

## Changes on CTAN

- 2016-09-19 Un Fonts core v1.0.2
  (the original archive "2607-un-fonts-core-1.0.2-080608.tar.gz" was re-packaged)
- 2017-06-04 updated based on Debian jessie (stable) package:
    "fonts-unfonts-core_1.0.2-080608-12_all.deb"

## Note

This bundle has been uploaded to CTAN by Hironobu Yamashita.
Inquiries and comments should be sent to <h.y.acetaminophen@gmail.com>.

Below is some additional notes from README.debian (included in ttf-unfonts-core)

## GPL and font embedding

These fonts are under the (pure) GNU General Public License, with no
exception about embedding in a document. So you should take care
about the license influence when your non-GPLed document embeds one of
these fonts.

This licensing problem has already been reported to the upstream years
ago but the upstream was not active on this discussion. Currently the
upstream looks dead.

For your information about this issue:

- The font embedding exception which FSF suggests:
  http://www.fsf.org/licensing/licenses/gpl-faq.html#FontException
- Fedora wiki page about font licensing:
  http://fedoraproject.org/wiki/SIGs/Fonts/Legal

More upstream information (in Korean):

- http://faq.ktug.or.kr/faq/%C0%BA%B1%DB%B2%C3

Hironobu Yamashita
2017-06-04
